package dirstate

type entryKey struct {
	dirname  string
	basename string
	fileID   string
}

type details struct {
	minikind    byte
	fingerprint string // varies depending on Minikind
	size        uint64
	executable  bool
}

type workingDetails struct {
	details
	packedHash string
}

type parentDetails struct {
	details
	revisionID string // maybe string
}

type entry struct {
	// TODO: I'm thinking entryKey may end up referenced elsewhere, so maybe
	//		 this should be a pointer. That way 3rd-party code can reference
	//		 just this object, without keeping 'entry' itself in memory
	key   entryKey
	work  workingDetails
	basis parentDetails
	extra []parentDetails
}

type block struct {
	dirname string
	entries []entry
}

const (
	/// "#bazaar dirstate flat format 3\n"
	HEADER_FORMAT_3 = "#bazaar dirstate flat format 3\n"
	ROOT_ID         = "TREE_ROOT"
	// "x"*32
	NULLSTAT = "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
)

const (
	NOT_IN_MEMORY = iota
	IN_MEMORY_UNMODIFIED
	IN_MEMORY_MODIFIED
	IN_MEMORY_HASH_MODIFIED
)

type headerInfo struct {
	Crc32      uint
	NumEntries uint
}

type State struct {
	headerState   int
	dirblockState int
	dirblocks     []block
	parents       []string
	ghosts        []string
	entries       []entry
}

func (s *State) NumEntries() int {
	return len(s.entries)
}

func New() (state *State) {
	blocks := make([]block, 0)
	state = &State{NOT_IN_MEMORY, NOT_IN_MEMORY, blocks, make([]string, 0),
		make([]string, 0), make([]entry, 0)}
	return
}

func (state *State) CreateRoot(rootID string) {
	state.headerState = IN_MEMORY_MODIFIED
	state.dirblockState = IN_MEMORY_MODIFIED
	root_block := block{"", make([]entry, 1)}
	state.dirblocks = append(state.dirblocks, root_block)
	root_entry := &root_block.entries[0]
	root_entry.key = entryKey{"", "", rootID}
	root_entry.work = workingDetails{details{'d', "", 0, false}, NULLSTAT}
	// root_entry.basis = parentDetails{}
	// root_entry.extra := make([]parentDetails, 0)
	// the first entry in dirblocks in the root object
	// the second entry in dirblocks is the entries *in* the root
	root_content_block := block{"", make([]entry, 0)}
	state.dirblocks = append(state.dirblocks, root_content_block)
	return
}

func (state *State) Parents() []string {
	return state.parents
}

func (state *State) Ghosts() []string {
	return state.ghosts
}
