
package main

import (
	"dirstate"
	"fmt"
	"os"
	"time"
)

func TickTock() chan int64 {
	cur_time := time.Nanoseconds()
	last_time := cur_time
	ch := make(chan int64)
	go func () {
		for ;;  {
			cur_time = time.Nanoseconds()
			delta := cur_time - last_time
			last_time = cur_time
			ch <- delta
		}
	}()
	return ch
}

func doParse() (numEntries int, err os.Error) {
	f, err := os.Open(".bzr/checkout/dirstate")
	if err != nil {
		fmt.Printf("Error opening: %s\n", err.String())
		return
	}
	state, err := dirstate.Parse(f)
	if err == nil {
		numEntries = state.NumEntries()
	}
	f.Close()
	return
}

const repeat_count = 10

func main() {
	fmt.Printf("Reading .bzr/checkout/dirstate\n")
	ns := time.Nanoseconds()
	var err os.Error
	var numEntries int
	for i := 0; i < repeat_count; i++ {
		numEntries, err = doParse()
		if err != nil {
			break
		}
	}
	ns_delta := time.Nanoseconds() - ns
	ns_f_delta := float64(ns_delta) / repeat_count / 1.0e6
	if err != nil {
		fmt.Printf("Error parsing:\n%s\n", err.String())
		return
	} else {
		fmt.Printf("%d loops %d entries in %.3fms\n",
				   repeat_count, numEntries, ns_f_delta)
	}
}

