/* Copyright (C) 2011 Canonical Ltd
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 *
 * This is the file which integrates between 'gotest' and 'gocheck' support for
 * creating suites of tests, etc.
 *
 */

package dirstate_test

import (
	"flag"
	"testing"
	"time"
	"os"

	. "launchpad.net/gocheck"
)

var fast = flag.Bool("fast", false, "Skip slow tests")

func TestAll(t *testing.T) {
	TestingT(t)
}

// This is the logging object that will be passed to all test cases.
type cLogger C

func (c *cLogger) Output(calldepth int, s string) os.Error {
	ns := time.Nanoseconds()
	t := float64(ns%100e9) / 1e9
	((*C)(c)).Logf("[LOG] %.05f %s", t, s)
	return nil
}

// This is the basic Suite type that all functions integrate around.
type S struct{}

var _ = Suite(&S{})

func (s *S) SetUpSuite(c *C) {
}

func (s *S) SetUpTest(c *C) {
}

func (s *S) TearDownTest(c *C) {
}
